#
# spec file for package python-python-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-utils
Version:        3.8.2
Release:        1.4
Summary:        Utilities not included with the standard Python install
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/WoLpH/python-utils
Source:         https://files.pythonhosted.org/packages/source/p/python-utils/python-utils-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing-extensions}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module loguru}
BuildRequires:  %{python_module pytest}
# /SECTION
Requires:       python-loguru
Requires:       python-typing-extensions
BuildArch:      noarch

%python_subpackages

%description
Python Utils is a collection of Python functions and
classes which make common patterns shorter and easier.

%prep
%setup -q -n python-utils-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
mv pytest.ini{,.hide}
skip='test_timeout_generator' # obs rq#1042418
%pytest -k "not $skip"
mv pytest.ini{.hide,}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Sun Feb  4 2024 Dirk Müller <dmueller@suse.com>
- update to 3.8.2:
  * Windows can also return an OSError instead of a ValueError
    for a `fromtimestamp` overflow
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- update to 3.8.1:
  * fixed silly typo
- update to 3.8.0:
  * Added slicabledeque
- update to 3.7.0:
  * Fixed several typing issues and added more thorough tests
- update to 3.6.1:
  * Increased `typing-extensions` version requirement to fix #38
- update to 3.6.0:
  * Added extra containers such as UniqueList and SlicableDeque.
    Added full pyright strict and mypy type checks
- update to 3.5.2:
  * Added import shortcuts for container classes
- update to 3.5.1:
  * Improved type hinting thanks to @jorenham
- update to 3.5.0:
  * Added unique list container
* Tue Dec 13 2022 pgajdos@suse.com
- disable flaky test_timeout_generator
* Mon Dec 12 2022 pgajdos@suse.com
- version update to 3.4.5
  * no upstream changelog, see
  https://github.com/wolph/python-utils/commits/develop
- python-six is not required
* Wed Dec  8 2021 pgajdos@suse.com
- do not require pytest-runner for build, it is not needed
* Sat Oct 23 2021 Axel Braun <axel.braun@gmx.de>
- version 2.5.6
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 2.4.0
  * added map/remap/scale/rescale function
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Ensure neutrality/relevance of description.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 2.3.0
  * Added several time methods and terminal size detection
- Fix tests
- spec file cleanups
* Tue Nov  7 2017 toddrme2178@gmail.com
- initial version
